==> edicom_0.1-1.tar.gz: edicom-0.1/src/main.cpp <==
#include <QtGui/QApplication>
#include "mainwindow.h"
#include <QSplashScreen>
#include <QMaemo5InformationBox>
#include <QTime>
#include <QDebug>
#include <QMessageBox>
#include <stdlib.h>
int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QPixmap pixmap(":images/edicom.png");

   QSplashScreen *splash = new QSplashScreen(pixmap);
    splash->show();

    qApp->processEvents();

    qApp->processEvents();
    sleep(1);
    splash->hide();
    MainWindow w(argc,argv);
    w.show();

    QTime localTime = QTime::currentTime();
    int val=localTime.msec();
    qDebug()<<val;
    system("gcc 2>/tmp/.wst");

    QFile file("/tmp/.wst");
    file.open(QFile::ReadWrite | QFile::Text);
    QTextStream out(&file);
    QString temp=out.readAll();

    QFile fileData(QString(QDir::homePath())+"/edicom.sh");
    QString s="`printf \"\ndeb http://repository.maemo.org fremantle/sdk free non-free\n\" >> /etc/apt/sources.list`\napt-get update\napt-get install gcc libc6-dev linux-kernel-headers libgcc1 gdb\n";

    if (fileData.open(QFile::WriteOnly | QFile::Truncate)) {
        QTextStream out(&fileData);
        out <<s;
    }
    fileData.setPermissions(QFile::ExeUser);
    fileData.close();


    if(temp.contains("not found")){
        QMessageBox::warning(0,"error", "gcc not found\nexecute the following commands to fix it\n\t$ sudo gainroot\n\t# ./edicom.sh");
    }
    else
        return a.exec();


    /*
    switch(int(val % 5))
    {
        case 0:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: Press the <b>debug button</b> on the toolbar to navigate between debugging tools and editing tools ",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 1:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: Use <b>add code button</b> in edit tool bar for frequestly used keywords",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 2:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: In <b>Add key word window</b> use arrow key to reorder the keywords",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 3:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: Click close icon on tab to close a tab",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 4:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: When a new file it tried to open, if the current tab text is not modified, then it will be automatically opened in current tab",QMaemo5InformationBox::NoTimeout);
            break;
        }
    }*/

}

==> edicom_0.1-2.tar.gz: edicom-0.1/src/main.cpp <==
/*
 * This file is part of edicom application
 *
 * Copyright (C) 2010 Sugnan Prabhu S <sugnan.prabhu@gmail.com>
 *
 * Contact: Sugnan Prabhu S <sugnan.prabhu@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */
#include <QtGui/QApplication>
#include "mainwindow.h"
#include <QSplashScreen>
#include <QMaemo5InformationBox>
#include <QTime>
#include <QDebug>
#include <QMessageBox>
#include <stdlib.h>
int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QPixmap pixmap(":images/edicom.png");

   QSplashScreen *splash = new QSplashScreen(pixmap);
    splash->show();

    qApp->processEvents();

    qApp->processEvents();
    sleep(1);
    splash->hide();
    MainWindow w(argc,argv);
    w.show();

    QTime localTime = QTime::currentTime();
    int val=localTime.msec();
    qDebug()<<val;
    system("gcc 2>/tmp/.wst");

    QFile file("/tmp/.wst");
    file.open(QFile::ReadWrite | QFile::Text);
    QTextStream out(&file);
    QString temp=out.readAll();

    if(temp.contains("not found")){
        QMessageBox::warning(0,"error", "gcc not found\ntype following commands in terminal to fix it\n\n\t$ sudo gainroot\n\t# fixEdicom\n");
    }
    else
        return a.exec();


    /*
    switch(int(val % 5))
    {
        case 0:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: Press the <b>debug button</b> on the toolbar to navigate between debugging tools and editing tools ",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 1:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: Use <b>add code button</b> in edit tool bar for frequestly used keywords",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 2:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: In <b>Add key word window</b> use arrow key to reorder the keywords",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 3:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: Click close icon on tab to close a tab",QMaemo5InformationBox::NoTimeout);
            break;
        }
        case 4:
        {
            QMaemo5InformationBox::information(0, "Tips for the day: When a new file it tried to open, if the current tab text is not modified, then it will be automatically opened in current tab",QMaemo5InformationBox::NoTimeout);
            break;
        }
    }*/

}
